Method: Xcake::Configuration::PreprocessorDefinitionsSettingProxy#key

Defined in:
lib/xcake/configuration/proxies/preproccessor_definitions_setting_proxy.rb

#keyString

Returns the key for the settings where the preprocessor definitions are kept.

Returns:

  • (String)

    the key for the settings where the preprocessor definitions are kept



20
21
22
# File 'lib/xcake/configuration/proxies/preproccessor_definitions_setting_proxy.rb', line 20

def key
  @key
end